/* Sistemas Integrados TECNISA
   Compras e Suprimentos

Nome: ACEITA_PEDCOTWEB

Descrio:
Realiza a gravao final do pedido de cotao preenchido pelos fornecedores
atravs do site de ecommerce, realizando ao mesmo tempo consistncias nos
dados informados:

IdMotNGerPedWeb - Identificador do motivo do no aceite.

IdMotNGerPedWeb [1] = '1' Fornecedor inativo
IdMotNGerPedWeb [2] = '1' Qualificao de fornecedor
IdMotNGerPedWeb [3] = '1' Fornecedor no atende  regio
IdMotNGerPedWeb [4] = '1' Produto no cadastrado para o fornecedor
IdMotNGerPedWeb [5] = '1' Qualificao de produto por fornecedor
IdMotNGerPedWeb [6] = '1' Qualificao de marca por produto
IdMotNGerPedWeb [7] = '1' Marca no ativa para o pedido de coleta

Criao:
27/05/2008 - Newton N. Santos

PARAMETROS:
@C:\WEB_501\SQL\END_CONV\ORACLE\8336_SUPSTPO_ACEITA_PEDCOTWEB.SQL
*/

CREATE OR REPLACE
PROCEDURE ACEITA_PEDCOTWEB
   (P_CDFILIAL     IN FILIAL.CDFILIAL%TYPE,
    P_NRPEDIDOCOL  IN PEDCOLGERAL.NRPEDIDOCOL%TYPE,
    P_IDCONSISTE   IN VARCHAR2,
    P_IDACEITEOK   OUT VARCHAR2)
IS

   V_CDFILIAL          PEDCOLGERAL.CDFILIAL%TYPE;
   V_CDFORNECED        FORNEPEDCOL.CDFORNECED%TYPE;
   V_CDREGIAO          REGIAOPEDCOL.CDREGIAO%TYPE;
   V_DTPEDCOLGERAL     PEDCOLGERAL.DTPEDCOLGERAL%TYPE;
   V_DTFINPERGERAL     PEDCOLGERAL.DTFINPERGERAL%TYPE;
   V_CDPRODUTO         PRMARCPEDCOL.CDPRODUTO%TYPE;
   V_CDARVPROD         PRODUTO.CDARVPROD%TYPE;
   V_CDMARCA           PRMARCPEDCOL.CDMARCA%TYPE;
   V_VRPRECUNIPRMARC   PRMARCPEDCOL.VRPRECUNIPRMARC%TYPE;
   V_IDSITUCADA        FORNECEDOR.IDSITUCADA%TYPE;
   V_CDQUALIF          FORNECEDOR.CDQUALIF%TYPE;
   V_IDFORNAUTO        FORNECEDOR.IDFORNAUTO%TYPE;
   V_DTVALQUALIF       FORNECEDOR.DTVALQUALIF%TYPE;

   V_COUNT             INT;
   V_COUNTAUX          INT;
   V_CDFORNAUX         FORNEPEDCOL.CDFORNECED%TYPE;

   V_ERRO_FORN_INAT    LOGNGERAPEDWEB.IDMOTNGERPEDWEB%TYPE;
   V_ERRO_FORN_QUAL    LOGNGERAPEDWEB.IDMOTNGERPEDWEB%TYPE;
   V_ERRO_FORN_REG     LOGNGERAPEDWEB.IDMOTNGERPEDWEB%TYPE;
   V_ERRO_PROD_FORN    LOGNGERAPEDWEB.IDMOTNGERPEDWEB%TYPE;
   V_ERRO_PROD_QUAL    LOGNGERAPEDWEB.IDMOTNGERPEDWEB%TYPE;
   V_ERRO_MARC_QUAL    LOGNGERAPEDWEB.IDMOTNGERPEDWEB%TYPE;
   V_ERRO_MARC_INAT    LOGNGERAPEDWEB.IDMOTNGERPEDWEB%TYPE;
   V_ERRO_MARC_NINF    LOGNGERAPEDWEB.IDMOTNGERPEDWEB%TYPE;

   CURSOR C_FORNREGPEDCOL IS
      SELECT
         PCG.CDFILIAL,
         PCG.DTFINPERGERAL,
         FPC.CDFORNECED,
         RPC.CDREGIAO,
         FORN.IDSITUCADA,
         FORN.CDQUALIF,
         FORN.IDFORNAUTO,
         FORN.DTVALQUALIF
      FROM
         PEDCOLGERAL PCG,
         FORNEPEDCOL FPC,
         REGIAOPEDCOL RPC,
         FORNECEDOR FORN
      WHERE
         PCG.CDFILIAL    = P_CDFILIAL    AND
         PCG.NRPEDIDOCOL = P_NRPEDIDOCOL AND
         FPC.CDFILIAL    = P_CDFILIAL    AND
         FPC.NRPEDIDOCOL = P_NRPEDIDOCOL AND
         RPC.CDFILIAL    = P_CDFILIAL    AND
         RPC.NRPEDIDOCOL = P_NRPEDIDOCOL AND
         FORN.CDFORNECED = FPC.CDFORNECED
      ORDER BY
         FPC.CDFORNECED,
         RPC.CDREGIAO;

   CURSOR C_PRMARCPEDCOL IS
      SELECT
         PCG.CDFILIAL,
         PCG.DTPEDCOLGERAL,
         PMPC.CDPRODUTO,
         PROD.CDARVPROD,
         PMPC.CDMARCA,
         PMPC.VRPRECUNIPRMARC
      FROM
         PEDCOLGERAL PCG,
         PRMARCPEDCOL PMPC,
         PRODUTO PROD
      WHERE
         (PCG.CDFILIAL     = P_CDFILIAL)      AND
         (PCG.NRPEDIDOCOL  = P_NRPEDIDOCOL)   AND
         (PMPC.CDFILIAL    = PCG.CDFILIAL)    AND
         (PMPC.NRPEDIDOCOL = PCG.NRPEDIDOCOL) AND
         (PROD.CDPRODUTO   = PMPC.CDPRODUTO)  AND
         (PMPC.VRPRECUNIPRMARC > 0);

   CURSOR C_FORNPEDCOL IS
      SELECT
         FPC.CDFORNECED
      FROM
         FORNEPEDCOL FPC
      WHERE
         FPC.CDFILIAL    = P_CDFILIAL    AND
         FPC.NRPEDIDOCOL = P_NRPEDIDOCOL
      ORDER BY
         FPC.CDFORNECED;

BEGIN
   P_IDACEITEOK := 'OK';

   V_ERRO_FORN_INAT := '1000000000';
   V_ERRO_FORN_QUAL := '0100000000';
   V_ERRO_FORN_REG  := '0010000000';
   V_ERRO_PROD_FORN := '0001000000';
   V_ERRO_PROD_QUAL := '0000100000';
   V_ERRO_MARC_QUAL := '0000010000';
   V_ERRO_MARC_INAT := '0000001000';
   V_ERRO_MARC_NINF := '0000000100';

   /* ---------------------------------------------------------------------- */
   /* Limpa a tabela que registra o log de inconsistncias antes de realizar */
   /* novo processo de aceite do pedido de cotao.                          */

   DELETE FROM LOGNGERAPEDWEB
   WHERE CDFILNGERPEDWEB = P_CDFILIAL
     AND NRPEDNGERPEDWEB = P_NRPEDIDOCOL;

   /* ---------------------------------------------------------------------- */

   V_CDFORNAUX := '';
   OPEN C_FORNREGPEDCOL;
   LOOP
      FETCH C_FORNREGPEDCOL INTO V_CDFILIAL, V_DTFINPERGERAL, V_CDFORNECED,
                                 V_CDREGIAO, V_IDSITUCADA, V_CDQUALIF,
                                 V_IDFORNAUTO, V_DTVALQUALIF;
      EXIT WHEN C_FORNREGPEDCOL%NOTFOUND;

      IF V_CDFORNECED <> V_CDFORNAUX THEN
         /* IdMotNGerPedWeb [1] = '1' Fornecedor inativo */
         IF V_IDSITUCADA = 'I' THEN

            IF P_IDCONSISTE = 'S' THEN
               P_IDACEITEOK := 'ERRO';

               INSERT INTO LOGNGERAPEDWEB
                 (CDFILNGERPEDWEB,
                  NRPEDNGERPEDWEB,
                  CDFORNGERPEDWEB,
                  CDREGNGERPEDWEB,
                  CDPRNGERPEDWEB,
                  CDMARNGERPEDWEB,
                  IDMOTNGERPEDWEB)
                VALUES
                 (P_CDFILIAL,
                  P_NRPEDIDOCOL,
                  V_CDFORNECED,
                  NULL,
                  NULL,
                  NULL,
                  V_ERRO_FORN_INAT);
            ELSE
               DELETE FROM PEDCOLETA
               WHERE
                  CDFILIAL    = P_CDFILIAL     AND
                  NRPEDIDOCOL = P_NRPEDIDOCOL  AND
                  CDFORNECED  = V_CDFORNECED;
            END IF;

         END IF;

         /* IdMotNGerPedWeb [2] = '1' Qualificao de fornecedor */
         SELECT
            COUNT(*)
         INTO
            V_COUNT
         FROM
            QUALIFICACAO,
            PARASUPRI
         WHERE
            (QUALIFICACAO.CDQUALIF = V_CDQUALIF) AND
            (PARASUPRI.CDFILIAL    = V_CDFILIAL) AND
            (V_IDFORNAUTO          = 'N')        AND
            ((QUALIFICACAO.IDPERCOTCMP = '2')                            OR
             ((PARASUPRI.IDULTIDTVALQ = 'D' AND V_DTFINPERGERAL > V_DTVALQUALIF) OR
              (PARASUPRI.IDULTIDTVALQ = 'M' AND V_DTFINPERGERAL > LAST_DAY(V_DTVALQUALIF))));

         IF V_COUNT <> 0 THEN

            IF P_IDCONSISTE = 'S' THEN
               P_IDACEITEOK := 'ERRO';

               INSERT INTO LOGNGERAPEDWEB
                 (CDFILNGERPEDWEB,
                  NRPEDNGERPEDWEB,
                  CDFORNGERPEDWEB,
                  CDREGNGERPEDWEB,
                  CDPRNGERPEDWEB,
                  CDMARNGERPEDWEB,
                  IDMOTNGERPEDWEB)
                VALUES
                 (P_CDFILIAL,
                  P_NRPEDIDOCOL,
                  V_CDFORNECED,
                  NULL,
                  NULL,
                  NULL,
                  V_ERRO_FORN_QUAL);
            ELSE
               DELETE FROM PEDCOLETA
               WHERE
                  CDFILIAL    = P_CDFILIAL     AND
                  NRPEDIDOCOL = P_NRPEDIDOCOL  AND
                  CDFORNECED  = V_CDFORNECED;
            END IF;

         END IF;

         V_CDFORNAUX := V_CDFORNECED;
      END IF;

      /* IdMotNGerPedWeb [3] = '1' Fornecedor no atende  regio */
      SELECT
         COUNT(*)
      INTO
         V_COUNT
      FROM
         REFOREG
      WHERE
         V_CDREGIAO   = REFOREG.CDREGIAO   AND
         V_CDFORNECED = REFOREG.CDFORNECED;

      IF V_COUNT <> 0 THEN

         IF P_IDCONSISTE = 'S' THEN
            P_IDACEITEOK := 'ERRO';

            INSERT INTO LOGNGERAPEDWEB
              (CDFILNGERPEDWEB,
               NRPEDNGERPEDWEB,
               CDFORNGERPEDWEB,
               CDREGNGERPEDWEB,
               CDPRNGERPEDWEB,
               CDMARNGERPEDWEB,
               IDMOTNGERPEDWEB)
             VALUES
              (P_CDFILIAL,
               P_NRPEDIDOCOL,
               V_CDFORNECED,
               V_CDREGIAO,
               NULL,
               NULL,
               V_ERRO_FORN_REG);
         ELSE
            DELETE FROM PEDCOLETA
            WHERE
               CDFILIAL    = P_CDFILIAL     AND
               NRPEDIDOCOL = P_NRPEDIDOCOL  AND
               CDFORNECED  = V_CDFORNECED   AND
               CDREGIAO    = V_CDREGIAO;
         END IF;

      END IF;

   END LOOP;
   CLOSE C_FORNREGPEDCOL;

   OPEN C_PRMARCPEDCOL;
   LOOP
      FETCH C_PRMARCPEDCOL INTO V_CDFILIAL, V_DTPEDCOLGERAL, V_CDPRODUTO,
                                V_CDARVPROD, V_CDMARCA, V_VRPRECUNIPRMARC;
      EXIT WHEN C_PRMARCPEDCOL%NOTFOUND;

      OPEN C_FORNPEDCOL;
      LOOP
         FETCH C_FORNPEDCOL INTO V_CDFORNECED;
         EXIT WHEN C_FORNPEDCOL%NOTFOUND;

         /* IdMotNGerPedWeb [4] = '1' Produto no cadastrado para o fornecedor */
         SELECT
            COUNT(*)
         INTO
            V_COUNT
         FROM
            PRODFORN,
            PRODUTO PRODUTO_PRODFORN
         WHERE
            (PRODFORN.CDPRODUTO  = PRODUTO_PRODFORN.CDPRODUTO) AND
            (PRODFORN.CDFORNECED = V_CDFORNECED)      AND
            (V_CDARVPROD LIKE PRODUTO_PRODFORN.CDARVPROD||'%');

         IF V_COUNT = 0 THEN

            IF P_IDCONSISTE = 'S' THEN

               P_IDACEITEOK := 'ERRO';

               INSERT INTO LOGNGERAPEDWEB
                 (CDFILNGERPEDWEB,
                  NRPEDNGERPEDWEB,
                  CDFORNGERPEDWEB,
                  CDREGNGERPEDWEB,
                  CDPRNGERPEDWEB,
                  CDMARNGERPEDWEB,
                  IDMOTNGERPEDWEB)
                VALUES
                 (P_CDFILIAL,
                  P_NRPEDIDOCOL,
                  V_CDFORNECED,
                  NULL,
                  V_CDPRODUTO,
                  NULL,
                  V_ERRO_PROD_FORN);
            ELSE
               DELETE FROM ITEMPEDCOL
               WHERE
                  CDFILIAL    = P_CDFILIAL     AND
                  CDFORNECED  = V_CDFORNECED   AND
                  CDPRODUTO   = V_CDPRODUTO    AND
                  NRPEDCOLETA IN (SELECT NRPEDCOLETA
                                  FROM PEDCOLETA
                                  WHERE
                                    CDFILIAL    = P_CDFILIAL AND
                                    NRPEDIDOCOL = P_NRPEDIDOCOL);
            END IF;

         END IF;

         /* IdMotNGerPedWeb [5] = '1' Qualificao de produto por fornecedor */
         SELECT
            COUNT(*)
         INTO
            V_COUNT
         FROM
            QFOPRODFORN,
            PARASUPRI
         WHERE
            (PARASUPRI.CDFILIAL     = V_CDFILIAL)   AND
            (QFOPRODFORN.CDPRODUTO  = V_CDPRODUTO)  AND
            (QFOPRODFORN.CDFORNECED = V_CDFORNECED) AND
            ((QFOPRODFORN.IDFORNAPROV = 'N'    AND QFOPRODFORN.IDFORNAUTOR = 'N') OR
             ((QFOPRODFORN.IDFORNAPROV = 'S')  AND
                ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                  V_DTPEDCOLGERAL > LAST_DAY(QFOPRODFORN.DTVALPRFORN)) OR
                 (PARASUPRI.IDULTIDTVALQ = 'D' AND
                  V_DTPEDCOLGERAL > QFOPRODFORN.DTVALPRFORN)) ) );

         IF V_COUNT <> 0 THEN

            IF P_IDCONSISTE = 'S' THEN

               P_IDACEITEOK := 'ERRO';

               INSERT INTO LOGNGERAPEDWEB
                 (CDFILNGERPEDWEB,
                  NRPEDNGERPEDWEB,
                  CDFORNGERPEDWEB,
                  CDREGNGERPEDWEB,
                  CDPRNGERPEDWEB,
                  CDMARNGERPEDWEB,
                  IDMOTNGERPEDWEB)
                VALUES
                 (P_CDFILIAL,
                  P_NRPEDIDOCOL,
                  V_CDFORNECED,
                  NULL,
                  V_CDPRODUTO,
                  NULL,
                  V_ERRO_PROD_QUAL);
            ELSE
               DELETE FROM ITEMPEDCOL
               WHERE
                  CDFILIAL    = P_CDFILIAL     AND
                  CDFORNECED  = V_CDFORNECED   AND
                  CDPRODUTO   = V_CDPRODUTO    AND
                  NRPEDCOLETA IN (SELECT NRPEDCOLETA
                                  FROM PEDCOLETA
                                  WHERE
                                    CDFILIAL    = P_CDFILIAL AND
                                    NRPEDIDOCOL = P_NRPEDIDOCOL);
            END IF;

         END IF;

      END LOOP;
      CLOSE C_FORNPEDCOL;

      /* IdMotNGerPedWeb [6] = '1' Qualificao de marca por produto */
      SELECT
         COUNT(*)
      INTO
         V_COUNT
      FROM
        QFOMARPROD,
        PARASUPRI
      WHERE
       (PARASUPRI.CDFILIAL   = V_CDFILIAL)  AND
       (QFOMARPROD.CDPRODUTO = V_CDPRODUTO) AND
       (QFOMARPROD.CDMARCA   = V_CDMARCA)   AND
       ((QFOMARPROD.IDAPRMARPRO = 'N' AND QFOMARPROD.IDAUTMARPRO = 'N') OR
        ((QFOMARPROD.IDAPRMARPRO = 'S') AND
           ((PARASUPRI.IDULTIDTVALQ = 'M' AND
             V_DTPEDCOLGERAL > LAST_DAY(QFOMARPROD.DTVALAPROVA)) OR
            (PARASUPRI.IDULTIDTVALQ = 'D' AND
             V_DTPEDCOLGERAL > QFOMARPROD.DTVALAPROVA))));

      SELECT
         COUNT(*)
      INTO
         V_COUNTAUX
      FROM
         (SELECT
            QFOMARPROD.CDMARCA
          FROM
            QFOMARPROD
          WHERE
            QFOMARPROD.CDPRODUTO = V_CDPRODUTO AND
            QFOMARPROD.CDMARCA   = V_CDMARCA

          UNION

          SELECT
            PARASUPRI.CDMARCA
          FROM
            PARASUPRI
          WHERE
            PARASUPRI.CDFILIAL     = V_CDFILIAL AND
            (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA IS NULL));

      IF NOT((V_COUNT = 0) AND (V_COUNTAUX <> 0)) THEN

         IF P_IDCONSISTE = 'S' THEN

            P_IDACEITEOK := 'ERRO';

            INSERT INTO LOGNGERAPEDWEB
              (CDFILNGERPEDWEB,
               NRPEDNGERPEDWEB,
               CDFORNGERPEDWEB,
               CDREGNGERPEDWEB,
               CDPRNGERPEDWEB,
               CDMARNGERPEDWEB,
               IDMOTNGERPEDWEB)
             VALUES
              (P_CDFILIAL,
               P_NRPEDIDOCOL,
               NULL,
               NULL,
               V_CDPRODUTO,
               V_CDMARCA,
               V_ERRO_MARC_QUAL);
         ELSE
            UPDATE PRMARCPEDCOL
            SET VRPRECUNIPRMARC = 0
            WHERE
               CDFILIAL    = P_CDFILIAL    AND
               NRPEDIDOCOL = P_NRPEDIDOCOL AND
               CDPRODUTO   = V_CDPRODUTO   AND
               CDMARCA     = V_CDMARCA;

            DELETE FROM ITEMPEDCOL
            WHERE
               CDFILIAL  = P_CDFILIAL  AND
               CDPRODUTO = V_CDPRODUTO AND
               CDMARCA   = V_CDMARCA   AND
               NRPEDCOLETA IN (SELECT NRPEDCOLETA
                               FROM PEDCOLETA
                               WHERE
                                 CDFILIAL    = P_CDFILIAL AND
                                 NRPEDIDOCOL = P_NRPEDIDOCOL);
         END IF;

      END IF;

      /* IdMotNGerPedWeb [7] = '1' Marca no ativa para o pedido de coleta */
      SELECT
         COUNT(*)
      INTO
         V_COUNT
      FROM
         MARCA
      WHERE
         (MARCA.CDMARCA = V_CDMARCA) AND
         (NVL(MARCA.IDMARCAATIVA, 'A') <> 'A');

      IF V_COUNT <> 0 THEN

         IF P_IDCONSISTE = 'S' THEN

            P_IDACEITEOK := 'ERRO';

            INSERT INTO LOGNGERAPEDWEB
              (CDFILNGERPEDWEB,
               NRPEDNGERPEDWEB,
               CDFORNGERPEDWEB,
               CDREGNGERPEDWEB,
               CDPRNGERPEDWEB,
               CDMARNGERPEDWEB,
               IDMOTNGERPEDWEB)
             VALUES
              (P_CDFILIAL,
               P_NRPEDIDOCOL,
               NULL,
               NULL,
               NULL,
               V_CDMARCA,
               V_ERRO_MARC_INAT);
         ELSE
            UPDATE PRMARCPEDCOL
            SET VRPRECUNIPRMARC = 0
            WHERE
               CDFILIAL    = P_CDFILIAL    AND
               NRPEDIDOCOL = P_NRPEDIDOCOL AND
               CDMARCA     = V_CDMARCA;

            DELETE FROM ITEMPEDCOL
            WHERE
               CDFILIAL  = P_CDFILIAL  AND
               CDMARCA   = V_CDMARCA   AND
               NRPEDCOLETA IN (SELECT NRPEDCOLETA
                               FROM PEDCOLETA
                               WHERE
                                 CDFILIAL    = P_CDFILIAL AND
                                 NRPEDIDOCOL = P_NRPEDIDOCOL);
         END IF;
      END IF;

      /* IdMotNGerPedWeb [8] = '1' Preo no informado para marca */
      IF V_VRPRECUNIPRMARC IS NULL THEN

         IF P_IDCONSISTE = 'S' THEN

            P_IDACEITEOK := 'ERRO';

            INSERT INTO LOGNGERAPEDWEB
              (CDFILNGERPEDWEB,
               NRPEDNGERPEDWEB,
               CDFORNGERPEDWEB,
               CDREGNGERPEDWEB,
               CDPRNGERPEDWEB,
               CDMARNGERPEDWEB,
               IDMOTNGERPEDWEB)
             VALUES
              (P_CDFILIAL,
               P_NRPEDIDOCOL,
               NULL,
               NULL,
               V_CDPRODUTO,
               V_CDMARCA,
               V_ERRO_MARC_NINF);
         ELSE
            UPDATE PRMARCPEDCOL
            SET VRPRECUNIPRMARC = 0
            WHERE
               CDFILIAL    = P_CDFILIAL    AND
               NRPEDIDOCOL = P_NRPEDIDOCOL AND
               CDPRODUTO   = V_CDPRODUTO   AND
               CDMARCA     = V_CDMARCA;

            DELETE FROM ITEMPEDCOL
            WHERE
               CDFILIAL  = P_CDFILIAL  AND
               CDPRODUTO = V_CDPRODUTO AND
               CDMARCA   = V_CDMARCA   AND
               NRPEDCOLETA IN (SELECT NRPEDCOLETA
                               FROM PEDCOLETA
                               WHERE
                                 CDFILIAL    = P_CDFILIAL AND
                                 NRPEDIDOCOL = P_NRPEDIDOCOL);
         END IF;
      END IF;

   END LOOP;
   CLOSE C_PRMARCPEDCOL;

   IF (P_IDCONSISTE <> 'S') OR (P_IDACEITEOK = 'OK') THEN

      OPEN C_PRMARCPEDCOL;
      LOOP
         FETCH C_PRMARCPEDCOL INTO V_CDFILIAL, V_DTPEDCOLGERAL, V_CDPRODUTO,
                                   V_CDARVPROD, V_CDMARCA, V_VRPRECUNIPRMARC;
         EXIT WHEN C_PRMARCPEDCOL%NOTFOUND;

         UPDATE ITEMPEDCOL
         SET ITEMPEDCOL.VRITEMPEDCOL = V_VRPRECUNIPRMARC
         WHERE ITEMPEDCOL.CDPRODUTO  = V_CDPRODUTO
           AND ITEMPEDCOL.CDMARCA    = V_CDMARCA
           AND  EXISTS (SELECT 1
                        FROM PEDCOLETA
                        WHERE PEDCOLETA.CDFILIAL    = ITEMPEDCOL.CDFILIAL
                          AND PEDCOLETA.NRPEDCOLETA = ITEMPEDCOL.NRPEDCOLETA
                          AND PEDCOLETA.CDREGIAO    = ITEMPEDCOL.CDREGIAO
                          AND PEDCOLETA.CDFORNECED  = ITEMPEDCOL.CDFORNECED
                          AND PEDCOLETA.CDFILIAL    = P_CDFILIAL
                          AND PEDCOLETA.NRPEDIDOCOL = P_NRPEDIDOCOL);

      END LOOP;
      CLOSE C_PRMARCPEDCOL;

      UPDATE PEDCOLGERAL SET
      IDSITUPEDCOLETA = 'A'
      WHERE CDFILIAL    = P_CDFILIAL
        AND NRPEDIDOCOL = P_NRPEDIDOCOL;

   END IF;

   COMMIT;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('ACEITA_PEDCOTWEB','5.05.005'); END;
/

